@@ -18,7 +18,7 @@
 #include <algorithm>
 #include <cwchar>
 
-#define FZSFTP_PROTOCOL_VERSION 7
+#define FZSFTP_PROTOCOL_VERSION 8
 
 struct sftp_message
 {
@@ -171,12 +171,12 @@ protected:
 			case sftpEvent::Hostkey:
 				lines = 1;
 				break;
+			case sftpEvent::AskHostkey:
+			case sftpEvent::AskHostkeyChanged:
 			case sftpEvent::AskHostkeyBetteralg:
 				lines = 2;
 				break;
 			case sftpEvent::Listentry:
-			case sftpEvent::AskHostkey:
-			case sftpEvent::AskHostkeyChanged:
 				lines = 3;
 				break;
 			};
@@ -572,7 +572,7 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 				DoClose(FZ_REPLY_INTERNALERROR);
 				break;
 			}
-			SendAsyncRequest(new CHostKeyNotification(message.text[0], port, message.text[2], message.type == sftpEvent::AskHostkeyChanged));
+			SendAsyncRequest(new CHostKeyNotification(message.text[0], port, m_sftpEncryptionDetails, message.type == sftpEvent::AskHostkeyChanged));
 		}
 		break;
 	case sftpEvent::AskHostkeyBetteralg:
@@ -666,7 +666,23 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 		m_sftpEncryptionDetails.macServerToClient = message.text[0];
 		break;
 	case sftpEvent::Hostkey:
-		m_sftpEncryptionDetails.hostKey = message.text[0];
+		{
+			auto tokens = fz::strtok(message.text[0], ' ');
+			if (!tokens.empty()) {
+				m_sftpEncryptionDetails.hostKeyFingerprintSHA256 = tokens.back();
+				tokens.pop_back();
+			}
+			if (!tokens.empty()) {
+				m_sftpEncryptionDetails.hostKeyFingerprintMD5 = tokens.back();
+				tokens.pop_back();
+			}
+			for (auto const& token : tokens) {
+				if (!m_sftpEncryptionDetails.hostKeyAlgorithm.empty()) {
+					m_sftpEncryptionDetails.hostKeyAlgorithm += ' ';
+				}
+				m_sftpEncryptionDetails.hostKeyAlgorithm += token;
+			}
+		}
 		break;
 	default:
 		wxFAIL_MSG(_T("given notification codes not handled"));
@@ -698,7 +714,7 @@ bool CSftpControlSocket::SendCommand(std::wstring const& cmd, std::wstring const
 	if (cmd.find('\n') != std::wstring::npos ||
 		cmd.find('\r') != std::wstring::npos)
 	{
-		LogMessage(MessageType::Debug_Warning, _T("Command containing newline characters, aborting"));
+		LogMessage(MessageType::Debug_Warning, _T("Command containing newline characters, aborting."));
 		ResetOperation(FZ_REPLY_INTERNALERROR);
 		return false;
 	}
@@ -822,7 +838,6 @@ public:
 	bool fallback_to_current{};
 
 	CDirectoryListing directoryListing;
-	int mtime_index{};
 
 	fz::monotonic_clock m_time_before_locking;
 };
@@ -1679,7 +1694,7 @@ int CSftpControlSocket::FileTransferSend()
 
 		fz::datetime t = pData->fileTime;
 		t -= fz::duration::from_minutes(m_pCurrentServer->GetTimezoneOffset());
-		
+
 		// Y2K38
 		time_t ticks = t.get_time_t();
 		std::wstring seconds = fz::sprintf(L"%d", ticks);
