@@ -35,8 +35,9 @@ CRecursiveOperationStatus::CRecursiveOperationStatus(wxWindow* parent, CState& s
 	SetSize(size);
 
 	// Position stop button
-	wxBitmap bmp = CThemeProvider::Get()->GetBitmap(_T("ART_CANCEL"), wxART_OTHER, CThemeProvider::GetIconSize(iconSizeSmall));
-	wxSize s = bmp.GetSize();
+	wxBitmap bmp = CThemeProvider::Get()->CreateBitmap(_T("ART_CANCEL"), wxART_OTHER, CThemeProvider::GetIconSize(iconSize24, false));
+	wxSize s = bmp.GetScaledSize();
+	s.IncBy(2);
 	s.IncBy(s.GetHeight() / 2);
 	auto button = new wxBitmapButton(this, wxID_ANY, bmp, wxPoint(10, (size.GetHeight() - s.GetHeight()) / 2), s);
 	button->SetToolTip(_("Stop recursive operation"));
@@ -115,8 +116,8 @@ void CRecursiveOperationStatus::UpdateText()
 
 		unsigned long long const countFiles = static_cast<unsigned long long>(operation->GetProcessedFiles());
 		unsigned long long const countDirs = static_cast<unsigned long long>(operation->GetProcessedDirectories());
-		const wxString files = wxString::Format(wxPLURAL_LL("%llu file", "%llu files", countFiles), countFiles);
-		const wxString dirs = wxString::Format(wxPLURAL_LL("%llu directory", "%llu directories", countDirs), countDirs);
+		std::wstring const files = fz::sprintf(fztranslate("%llu file", "%llu files", countFiles), countFiles);
+		std::wstring const dirs = fz::sprintf(fztranslate("%llu directory", "%llu directories", countDirs), countDirs);
 		// @translator: Example: Processed 5 files in 1 directory
 		m_pTextCtrl[1]->SetLabel(wxString::Format(_("Processed %s in %s."), files, dirs));
 	}
